#!/usr/bin/env node

import { resolve } from 'path'
import * as program from 'commander'
import * as spinner from './spinner'
import copyTemplate from './init/copy-template'
import setMetaInformation from './init/set-meta-information'
import installDependencies from './init/install-dependencies'

let appName
const pkg = require(resolve(__dirname, '../../package.json'))

program
  .version(pkg.version)
  .arguments('<name>')
  .action(function(name) {
    appName = name
  })

program.parse(process.argv)

if (typeof appName === 'undefined') {
  appName = 'my-app'
}

async function init(name: string): Promise<void> {
  const templatePath = resolve(__dirname, '../../template/base')
  const targetPath = resolve(process.cwd(), name)

  await copyTemplate(templatePath, targetPath)
  await setMetaInformation(targetPath, name)

  const pm = await installDependencies(targetPath)
  const cmd = pm === 'yarn' ? 'yarn start' : 'npm start'
  spinner.clear(`Run \`${cmd}\` inside of "${name}" to start the app`)
}

init(appName)
