import 'reflect-metadata'
import { resolve } from 'path'
import * as express from 'express'
import { Request, Response } from 'express'
import * as next from 'next'
import { createConnection } from 'typeorm'
import config from './config'
import { isNextRoute } from './util'

const dev: boolean = process.env.NODE_ENV !== 'production'
const port: number = 4000
const webDir: string = resolve(__dirname, '..')

createConnection(config).then(async (): Promise<void> => {
  const app = next({ dev, dir: webDir })
  const handleByNext = app.getRequestHandler()

  app
    .prepare()
    .then(() => {
      const server = express()
      server.use(express.json())

      server.get('/_next/*', (req: Request, res: Response) => {
        handleByNext(req, res)
      })

      server.get('/static/*', (req: Request, res: Response) => {
        handleByNext(req, res)
      })

      if (!dev) {
        server.set('trust proxy', 1) // trust first proxy
      }

      server.get('*', async (req: Request, res: Response): Promise<void> => {
        if (await isNextRoute(req.path, webDir)) {
          handleByNext(req, res)
        } else {
          res.send({
            status: 200,
            message: 'hello api'
          })
        }
      })

      server.listen(port, (err) => {
        if (err) {
          throw err
        }
        console.log(`> READY on http://localhost:${port}`)
      })
    })
})
