import { resolve } from 'path'

const isTest: boolean = process.env.NODE_ENV !== 'testing'
const baseDir: string = isTest ? resolve(__dirname, '../../..') : process.cwd()

require('dotenv').config({
  path: baseDir
})

const config: any = {
  type: process.env.DB_TYPE || 'sqlite',
  host: process.env.DB_HOST || '',
  port: process.env.DB_PORT || '',
  username: process.env.DB_USERNAME || '',
  password: process.env.DB_PASSWORD || '',
  database: process.env.DB_DATABASE || '.ezadmin/storage/database.sqlite',
  synchronize: process.env.DB_SYNCHRONIZE || true,
  logging: process.env.DB_LOGGING || true,
  entities: [
    resolve(baseDir, '.ezadmin/web/entity/**/*.ts')
  ],
  migrations: [
    resolve(baseDir, '.ezadmin/web/migration/**/*.ts')
  ],
  subscribers: [
    resolve(baseDir, '.ezadmin/web/subscriber/**/*.ts')
  ],
  cli: {
    entitiesDir: resolve(baseDir, '.ezadmin/web/entity'),
    migrationsDir: resolve(baseDir, '.ezadmin/web/migration'),
    subscribersDir: resolve(baseDir, '.ezadmin/web/subscriber')
  }
}

export default config
